# Subutai Bazaar

A Python library for the Bazaar REST API. Check out [Subutai](https://subutai.io) and [Bazaar](https://bazaar.subutai.io) websites for more information.

This library requires `requests` package, which can be installed with PyPi:

```
pip install requests
```
